Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// JID defines an initial session JID.
JID *jid.JID
// Transport provides the underlying session transport
// that will be used to send and received elements.
Transport transport.Transport
// MaxStanzaSize defines the maximum stanza size that
// can be read from the session transport.
MaxStanzaSize int
// Remote domain represents the remote receiving entity domain name.
RemoteDomain string
// IsServer defines whether or not this session is established
// by the server.
IsServer bool
// IsInitiating defines whether or not this is an initiating
// entity session.
IsInitiating bool
}
A Config structure is used to configure an XMPP session.
type Error ¶
type Error struct {
// Element returns the original incoming element that generated
// the session error.
Element xml.XElement
// UnderlyingErr is the underlying session error.
UnderlyingErr error
}
Error represents a session error.
type Session ¶
type Session struct {
// contains filtered or unexported fields
}
Session represents an XMPP session between the two peers.
func (*Session) Close ¶
Close closes session sending the proper XMPP payload. Is responsability of the caller to close underlying transport.
func (*Session) SetRemoteDomain ¶
SetRemoteDomain sets current session remote domain.
Click to show internal directories.
Click to hide internal directories.